import {Component, OnInit} from '@angular/core';
import {NavigationService} from "@service/navigation.service";
import {MatFormFieldModule} from "@angular/material/form-field";
import SetupService from "@api/v1/setup.service";
import {DatabaseResponse} from "@api/v1/configuration/databaseResponse";
import {CacheResponse} from "@api/v1/configuration/cacheResponse";
import {PasswordPolicy} from "@model/passwordPolicy";
import {UserResponse} from "@api/v1/userResponse";
import {LoggingRequest} from "@api/v1/configuration/loggingRequest";
import {ScheduleConfigurationRequest} from "@api/v1/configuration/scheduleConfigurationRequest";
import {MatExpansionModule} from "@angular/material/expansion";

@Component({
  selector: 'app-summary',
  standalone: true,
  imports: [MatFormFieldModule, MatExpansionModule],
  templateUrl: './summary.component.html'
})

export class SummaryComponent implements OnInit {
  databaseConfig: DatabaseResponse | undefined;
  cacheConfig: CacheResponse | undefined;
  passwordPolicyConfig: PasswordPolicy | undefined;
  adminConfig: UserResponse | undefined;
  loggingConfig: LoggingRequest | undefined;
  scheduleConfig: ScheduleConfigurationRequest | undefined;

  constructor(private navigationService: NavigationService, private api: SetupService) {
    this.navigationService.nextButtonAction = () => {
      return this.api.submit();
    };
    this.navigationService.setNextButtonState(true);
  }

  ngOnInit(): void {
    this.api.databaseConfiguration().subscribe(config => {
      this.databaseConfig = config;
    });

    this.api.cacheConfiguration().subscribe(config => {
      this.cacheConfig = config;
    });

    this.api.passwordPolicyConfiguration().subscribe(config => {
      this.passwordPolicyConfig = config;
    });

    this.api.adminConfiguration().subscribe(config => {
      this.adminConfig = config;
    });

    this.api.loggingConfiguration().subscribe(config => {
      this.loggingConfig = config;
    });

    this.api.scheduleConfiguration().subscribe(config => {
      this.scheduleConfig = config;
    });
  }
}
