import {Injectable} from '@angular/core';
import {BehaviorSubject, Observable, Subject} from "rxjs";

@Injectable({
  providedIn: 'root'
})
export class NavigationService {
  private nextButtonState = new BehaviorSubject<boolean>(false);
  private skipButtonState = new BehaviorSubject<boolean>(false);
  private autoSkipNavigationSubject = new Subject<() => Observable<boolean>>();
  private isUserInitiatedNavigation = false;

  nextButtonState$ = this.nextButtonState.asObservable();
  skipButtonState$ = this.skipButtonState.asObservable();
  autoSkipNavigation$ = this.autoSkipNavigationSubject.asObservable();

  skipButtonAction!: () => Observable<boolean>;
  nextButtonAction!: () => Observable<boolean>;

  setNextButtonState(state: boolean) {
    this.nextButtonState.next(state);
  }

  setSkipButtonState(state: boolean) {
    this.skipButtonState.next(state);
  }

  resetButtonStates() {
    this.setNextButtonState(false);
    this.setSkipButtonState(false);
  }

  setUserInitiatedNavigation(isUserInitiated: boolean) {
    this.isUserInitiatedNavigation = isUserInitiated;
  }

  get isNavigationUserInitiated() {
    return this.isUserInitiatedNavigation;
  }

  triggerAutoSkip(action: () => Observable<boolean>) {
    this.autoSkipNavigationSubject.next(action);
  }
}
